# People-also-ask-it Api

#intelligenzaartificialeitalia.net

## Installation
```
pip install people_also_ask_it
```


### Importing
```python
import people_also_ask_it
```

### Come ottenere domande correlate
```python
people_also_ask_it.get_related_questions("caffè")

```

### Come ottenere più domande
```python
people_also_ask_it.get_related_questions("coffee", 5)

```

### Ottieni una risposta semplice per una domanda
```python
people_also_ask_it.get_simple_answer("Cosa è il caffè?")

```

##Licenza

MIT

© Copyright 2020-2022 Intelligenza Artificiale Italia!
